Module oracle

Module oracle 

Structs

InvalidOracleConfig
OracleConfig
Oracle configuration stored by vault and asset accounts.
OraclePrice
A fixed-point oracle price: value / 10^decimals quote units per one whole token of the priced asset (standard market convention).
PythOracleConfig
Pyth pull-oracle configuration stored with the asset it prices.
SwitchboardOracleConfig
Switchboard On-Demand oracle configuration stored with the asset it prices.

Enums

OracleKind
Discriminator for oracle implementations.