Module state

Module state 

Account wire types shared with off-chain readers.

Re-exports

pub use asset::Asset;
pub use vault::Role;
pub use vault::Vault;
pub use vault::VaultControls;

Modules

asset
Asset account wire type and decode helpers — a vault’s per-asset oracle registration for a non-base deposit asset (off-chain readers decode it to learn how the asset prices, including whether it routes through the vault base_oracle).
vault
Vault account wire type and decode helpers.

Constants

ASSET_ACCOUNT_TAG
Tag byte that prefixes an Asset payload in the program’s tagged Account.
VAULT_ACCOUNT_TAG
Tag byte that prefixes a Vault payload in the program’s tagged Account.