Account wire types shared with off-chain readers.
Re-exports
pub use asset::Asset;pub use vault::Role;pub use vault::Vault;pub use vault::VaultControls;
Modules
- asset
Assetaccount wire type and decode helpers — a vault’s per-asset oracle registration for a non-base deposit asset (off-chain readers decode it to learn how the asset prices, including whether it routes through the vaultbase_oracle).- vault
Vaultaccount wire type and decode helpers.
Constants
- ASSET_
ACCOUNT_ TAG - Tag byte that prefixes an
Assetpayload in the program’s taggedAccount. - VAULT_
ACCOUNT_ TAG - Tag byte that prefixes a
Vaultpayload in the program’s taggedAccount.